#!/bin/bash
# GinVoice - Creating LaTeX invoices with a GTK GUI
# Copyright (C) 2021  Erik Nijenhuis <erik@xerdi.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

DATA_DIR="debian/tmp"
TARGET="debian/install"
PROJECT_DIRECTORY="$(git rev-parse --show-toplevel)"

cd "$PROJECT_DIRECTORY"
echo "# Generated by scripts/packres.sh" > $TARGET
mkdir -p "$DATA_DIR"

cp res/ginvoice.desktop $DATA_DIR/
cp res/css/style.css $DATA_DIR/
cp res/basic_template.tar.gz $DATA_DIR/

echo "ginvoice.desktop usr/share/applications" >> $TARGET
echo "style.css usr/lib/ginvoice" >> $TARGET
echo "basic_template.tar.gz usr/lib/ginvoice/templates" >> $TARGET

for f in res/glade/*.glade; do
  cp $f $DATA_DIR/
  echo "$(basename $f) usr/lib/ginvoice" >> $TARGET
done

for f in res/icon/*; do
  resolution="$(basename $f | cut -d 'x' -f 1)"
  mkdir -p "$DATA_DIR/$resolution"
  cp "$f/ginvoice.png" "$DATA_DIR/$resolution"
  echo "$resolution/ginvoice.png usr/share/icons/hicolor/${resolution}x${resolution}/apps" >> $TARGET
done

for f in res/po/*.po; do
  lang=$(basename $f | cut -d '.' -f 1)
  target="$DATA_DIR/locale/$lang/LC_MESSAGES"
  mkdir -p "$target"
  msgfmt "$f" -o "$target/ginvoice.mo"
  echo "$target/ginvoice.mo usr/share/locale/$lang/LC_MESSAGES" >> $TARGET
done

echo '========================================================================================================================'
echo 'DATA FILES:'
ls $DATA_DIR
echo '========================================================================================================================'
